#!/usr/bin/env node
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));

// src/index.ts
var import_commander = require("commander");
var import_shelljs = __toESM(require("shelljs"));

// src/services/encryptService.ts
var import_crypto = require("crypto");
var EncryptService = /* @__PURE__ */ __name(class EncryptService2 {
  constructor(secret) {
    this.secret = secret;
    this.algorithm = "aes-256-cbc";
  }
  makeCipheriv(secret, iv) {
    return (0, import_crypto.createCipheriv)(this.algorithm, secret, Buffer.from(iv, "hex"));
  }
  makeDecipheriv(secret, iv) {
    return (0, import_crypto.createDecipheriv)(this.algorithm, secret, Buffer.from(iv, "hex"));
  }
  async encryptText(text, iv) {
    const cipher = this.makeCipheriv(this.secret, iv);
    const encrypted = Buffer.concat([
      cipher.update(text),
      cipher.final()
    ]);
    return encrypted.toString("hex");
  }
  async decryptText(hash, iv) {
    const decipher = this.makeDecipheriv(this.secret, iv);
    const decrypted = Buffer.concat([
      decipher.update(Buffer.from(hash, "hex")),
      decipher.final()
    ]);
    return decrypted.toString();
  }
}, "EncryptService");
var encryptService_default = EncryptService;

// src/index.ts
var Main = /* @__PURE__ */ __name(class Main2 {
  constructor() {
    this.command = new import_commander.Command();
    this.shellJs = import_shelljs.default;
  }
  async getIvHash() {
    const iv = process.env.IV_HASH;
    if (!iv)
      throw new Error("iv is null");
    return iv;
  }
  async registerClIIInstance() {
    this.command.name("fcrypt").description("CLI to encrypt and decrypt text").version("0.0.1");
  }
  async registerCommands() {
    this.command.command("encrypt").version("0.1").alias("enc").argument("<value>", "string to encrypt").argument("<secret>", "secret to encrypt").description("encrypt any text").action(async (stringValue, secret) => {
      const iv = await this.getIvHash();
      const encryptService = new encryptService_default(secret);
      const encryptValue = await encryptService.encryptText(stringValue, iv);
      this.shellJs.echo("Value encrypted !");
      this.shellJs.echo(encryptValue);
    });
    this.command.command("decrypt").version("0.1").alias("dec").argument("<value>", "string to decrypt").argument("<secret>", "secret to decrypt").description("decrypt any text with secret").action(async (stringValue, secret) => {
      const encryptService = new encryptService_default(secret);
      const iv = await this.getIvHash();
      const decryptedValue = await encryptService.decryptText(stringValue, iv);
      this.shellJs.echo("Value decrypted !");
      this.shellJs.echo(decryptedValue);
    });
    this.command.parse(process.argv);
  }
  async run() {
    await this.registerClIIInstance();
    await this.registerCommands();
  }
}, "Main");
(async () => {
  const main = new Main();
  await main.run();
})();
