#!/usr/bin/env node
var __defProp = Object.defineProperty;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __esm = (fn, res) => function __init() {
  return fn && (res = (0, fn[__getOwnPropNames(fn)[0]])(fn = 0)), res;
};
var __commonJS = (cb, mod) => function __require() {
  return mod || (0, cb[__getOwnPropNames(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
};

// src/services/encryptService.ts
import { createCipheriv, createDecipheriv } from "crypto";
var EncryptService, encryptService_default;
var init_encryptService = __esm({
  "src/services/encryptService.ts"() {
    "use strict";
    EncryptService = /* @__PURE__ */ __name(class EncryptService2 {
      constructor(secret) {
        this.secret = secret;
        this.algorithm = "aes-256-cbc";
      }
      makeCipheriv(secret, iv) {
        return createCipheriv(this.algorithm, secret, Buffer.from(iv, "hex"));
      }
      makeDecipheriv(secret, iv) {
        return createDecipheriv(this.algorithm, secret, Buffer.from(iv, "hex"));
      }
      async encryptText(text, iv) {
        const cipher = this.makeCipheriv(this.secret, iv);
        const encrypted = Buffer.concat([
          cipher.update(text),
          cipher.final()
        ]);
        return encrypted.toString("hex");
      }
      async decryptText(hash, iv) {
        const decipher = this.makeDecipheriv(this.secret, iv);
        const decrypted = Buffer.concat([
          decipher.update(Buffer.from(hash, "hex")),
          decipher.final()
        ]);
        return decrypted.toString();
      }
    }, "EncryptService");
    encryptService_default = EncryptService;
  }
});

// src/index.ts
import { Command } from "commander";
import shelljs from "shelljs";
var require_src = __commonJS({
  "src/index.ts"() {
    init_encryptService();
    var Main = /* @__PURE__ */ __name(class Main {
      constructor() {
        this.command = new Command();
        this.shellJs = shelljs;
      }
      async getIvHash() {
        const iv = process.env.IV_HASH;
        if (!iv)
          throw new Error("iv is null");
        return iv;
      }
      async registerClIIInstance() {
        this.command.name("fcrypt").description("CLI to encrypt and decrypt text").version("0.0.1");
      }
      async registerCommands() {
        this.command.command("encrypt").version("0.1").alias("enc").argument("<value>", "string to encrypt").argument("<secret>", "secret to encrypt").description("encrypt any text").action(async (stringValue, secret) => {
          const iv = await this.getIvHash();
          const encryptService = new encryptService_default(secret);
          const encryptValue = await encryptService.encryptText(stringValue, iv);
          this.shellJs.echo("Value encrypted !");
          this.shellJs.echo(encryptValue);
        });
        this.command.command("decrypt").version("0.1").alias("dec").argument("<value>", "string to decrypt").argument("<secret>", "secret to decrypt").description("decrypt any text with secret").action(async (stringValue, secret) => {
          const encryptService = new encryptService_default(secret);
          const iv = await this.getIvHash();
          const decryptedValue = await encryptService.decryptText(stringValue, iv);
          this.shellJs.echo("Value decrypted !");
          this.shellJs.echo(decryptedValue);
        });
        this.command.parse(process.argv);
      }
      async run() {
        await this.registerClIIInstance();
        await this.registerCommands();
      }
    }, "Main");
    (async () => {
      const main = new Main();
      await main.run();
    })();
  }
});
export default require_src();
